Uses of Class
com.langfuse.client.core.RequestOptions
Packages that use RequestOptions
Package
Description
-
Uses of RequestOptions in com.langfuse.client.core
Methods in com.langfuse.client.core that return RequestOptionsMethods in com.langfuse.client.core with parameters of type RequestOptionsModifier and TypeMethodDescriptionClientOptions.headers(RequestOptions requestOptions) okhttp3.OkHttpClientClientOptions.httpClientWithTimeout(RequestOptions requestOptions) -
Uses of RequestOptions in com.langfuse.client.resources.annotationqueues
Methods in com.langfuse.client.resources.annotationqueues with parameters of type RequestOptionsModifier and TypeMethodDescriptionAnnotationQueuesClient.createQueueItem(String queueId, CreateAnnotationQueueItemRequest request, RequestOptions requestOptions) Add an item to an annotation queueAnnotationQueuesClient.deleteQueueItem(String queueId, String itemId, RequestOptions requestOptions) Remove an item from an annotation queueAnnotationQueuesClient.getQueue(String queueId, RequestOptions requestOptions) Get an annotation queue by IDAnnotationQueuesClient.getQueueItem(String queueId, String itemId, RequestOptions requestOptions) Get a specific item from an annotation queueAnnotationQueuesClient.listQueueItems(String queueId, GetAnnotationQueueItemsRequest request, RequestOptions requestOptions) Get items for a specific annotation queueAnnotationQueuesClient.listQueues(GetAnnotationQueuesRequest request, RequestOptions requestOptions) Get all annotation queuesAnnotationQueuesClient.updateQueueItem(String queueId, String itemId, UpdateAnnotationQueueItemRequest request, RequestOptions requestOptions) Update an annotation queue item -
Uses of RequestOptions in com.langfuse.client.resources.comments
Methods in com.langfuse.client.resources.comments with parameters of type RequestOptionsModifier and TypeMethodDescriptionCommentsClient.create(CreateCommentRequest request, RequestOptions requestOptions) Create a comment.CommentsClient.get(GetCommentsRequest request, RequestOptions requestOptions) Get all commentsCommentsClient.getById(String commentId, RequestOptions requestOptions) Get a comment by id -
Uses of RequestOptions in com.langfuse.client.resources.datasetitems
Methods in com.langfuse.client.resources.datasetitems with parameters of type RequestOptionsModifier and TypeMethodDescriptionDatasetItemsClient.create(CreateDatasetItemRequest request, RequestOptions requestOptions) Create a dataset itemDatasetItemsClient.delete(String id, RequestOptions requestOptions) Delete a dataset item and all its run items.DatasetItemsClient.get(String id, RequestOptions requestOptions) Get a dataset itemDatasetItemsClient.list(GetDatasetItemsRequest request, RequestOptions requestOptions) Get dataset items -
Uses of RequestOptions in com.langfuse.client.resources.datasetrunitems
Methods in com.langfuse.client.resources.datasetrunitems with parameters of type RequestOptionsModifier and TypeMethodDescriptionDatasetRunItemsClient.create(CreateDatasetRunItemRequest request, RequestOptions requestOptions) Create a dataset run itemvoidDatasetRunItemsClient.list(ListDatasetRunItemsRequest request, RequestOptions requestOptions) List dataset run items -
Uses of RequestOptions in com.langfuse.client.resources.datasets
Methods in com.langfuse.client.resources.datasets with parameters of type RequestOptionsModifier and TypeMethodDescriptionDatasetsClient.create(CreateDatasetRequest request, RequestOptions requestOptions) Create a datasetDatasetsClient.deleteRun(String datasetName, String runName, RequestOptions requestOptions) Delete a dataset run and all its run items.DatasetsClient.get(String datasetName, RequestOptions requestOptions) Get a datasetDatasetsClient.getRun(String datasetName, String runName, RequestOptions requestOptions) Get a dataset run and its itemsDatasetsClient.getRuns(String datasetName, GetDatasetRunsRequest request, RequestOptions requestOptions) Get dataset runsDatasetsClient.list(GetDatasetsRequest request, RequestOptions requestOptions) Get all datasets -
Uses of RequestOptions in com.langfuse.client.resources.health
Methods in com.langfuse.client.resources.health with parameters of type RequestOptionsModifier and TypeMethodDescriptionHealthClient.health(RequestOptions requestOptions) Check health of API and database -
Uses of RequestOptions in com.langfuse.client.resources.ingestion
Methods in com.langfuse.client.resources.ingestion with parameters of type RequestOptionsModifier and TypeMethodDescriptionIngestionClient.batch(IngestionRequest request, RequestOptions requestOptions) Batched ingestion for Langfuse Tracing. -
Uses of RequestOptions in com.langfuse.client.resources.media
Methods in com.langfuse.client.resources.media with parameters of type RequestOptionsModifier and TypeMethodDescriptionMediaClient.get(String mediaId, RequestOptions requestOptions) Get a media recordMediaClient.getUploadUrl(GetMediaUploadUrlRequest request, RequestOptions requestOptions) Get a presigned upload URL for a media recordvoidMediaClient.patch(String mediaId, PatchMediaBody request, RequestOptions requestOptions) Patch a media record -
Uses of RequestOptions in com.langfuse.client.resources.metrics
Methods in com.langfuse.client.resources.metrics with parameters of type RequestOptionsModifier and TypeMethodDescriptionMetricsClient.metrics(GetMetricsRequest request, RequestOptions requestOptions) Get metrics from the Langfuse project using a query object -
Uses of RequestOptions in com.langfuse.client.resources.models
Methods in com.langfuse.client.resources.models with parameters of type RequestOptionsModifier and TypeMethodDescriptionModelsClient.create(CreateModelRequest request, RequestOptions requestOptions) Create a modelvoidModelsClient.delete(String id, RequestOptions requestOptions) Delete a model.ModelsClient.get(String id, RequestOptions requestOptions) Get a modelModelsClient.list(GetModelsRequest request, RequestOptions requestOptions) Get all models -
Uses of RequestOptions in com.langfuse.client.resources.observations
Methods in com.langfuse.client.resources.observations with parameters of type RequestOptionsModifier and TypeMethodDescriptionObservationsClient.get(String observationId, RequestOptions requestOptions) Get a observationObservationsClient.getMany(GetObservationsRequest request, RequestOptions requestOptions) Get a list of observations -
Uses of RequestOptions in com.langfuse.client.resources.organizations
Methods in com.langfuse.client.resources.organizations with parameters of type RequestOptionsModifier and TypeMethodDescriptionOrganizationsClient.getOrganizationMemberships(RequestOptions requestOptions) Get all memberships for the organization associated with the API key (requires organization-scoped API key)OrganizationsClient.getOrganizationProjects(RequestOptions requestOptions) Get all projects for the organization associated with the API key (requires organization-scoped API key)OrganizationsClient.getProjectMemberships(String projectId, RequestOptions requestOptions) Get all memberships for a specific project (requires organization-scoped API key)OrganizationsClient.updateOrganizationMembership(MembershipRequest request, RequestOptions requestOptions) Create or update a membership for the organization associated with the API key (requires organization-scoped API key)OrganizationsClient.updateProjectMembership(String projectId, MembershipRequest request, RequestOptions requestOptions) Create or update a membership for a specific project (requires organization-scoped API key). -
Uses of RequestOptions in com.langfuse.client.resources.projects
Methods in com.langfuse.client.resources.projects with parameters of type RequestOptionsModifier and TypeMethodDescriptionProjectsClient.create(CreateProjectRequest request, RequestOptions requestOptions) Create a new project (requires organization-scoped API key)ProjectsClient.createApiKey(String projectId, CreateApiKeyRequest request, RequestOptions requestOptions) Create a new API key for a project (requires organization-scoped API key)ProjectsClient.delete(String projectId, RequestOptions requestOptions) Delete a project by ID (requires organization-scoped API key).ProjectsClient.deleteApiKey(String projectId, String apiKeyId, RequestOptions requestOptions) Delete an API key for a project (requires organization-scoped API key)ProjectsClient.get(RequestOptions requestOptions) Get Project associated with API keyProjectsClient.getApiKeys(String projectId, RequestOptions requestOptions) Get all API keys for a project (requires organization-scoped API key)ProjectsClient.update(String projectId, UpdateProjectRequest request, RequestOptions requestOptions) Update a project by ID (requires organization-scoped API key). -
Uses of RequestOptions in com.langfuse.client.resources.prompts
Methods in com.langfuse.client.resources.prompts with parameters of type RequestOptionsModifier and TypeMethodDescriptionPromptsClient.create(CreatePromptRequest request, RequestOptions requestOptions) Create a new version for the prompt with the givennamePromptsClient.get(String promptName, GetPromptRequest request, RequestOptions requestOptions) Get a promptPromptsClient.list(ListPromptsMetaRequest request, RequestOptions requestOptions) Get a list of prompt names with versions and labels -
Uses of RequestOptions in com.langfuse.client.resources.promptversion
Methods in com.langfuse.client.resources.promptversion with parameters of type RequestOptionsModifier and TypeMethodDescriptionPromptVersionClient.update(String name, int version, UpdatePromptRequest request, RequestOptions requestOptions) Update labels for a specific prompt version -
Uses of RequestOptions in com.langfuse.client.resources.scim
Methods in com.langfuse.client.resources.scim with parameters of type RequestOptionsModifier and TypeMethodDescriptionScimClient.createUser(CreateUserRequest request, RequestOptions requestOptions) Create a new user in the organization (requires organization-scoped API key)ScimClient.deleteUser(String userId, RequestOptions requestOptions) Remove a user from the organization (requires organization-scoped API key).ScimClient.getResourceTypes(RequestOptions requestOptions) Get SCIM Resource Types (requires organization-scoped API key)ScimClient.getSchemas(RequestOptions requestOptions) Get SCIM Schemas (requires organization-scoped API key)ScimClient.getServiceProviderConfig(RequestOptions requestOptions) Get SCIM Service Provider Configuration (requires organization-scoped API key)ScimClient.getUser(String userId, RequestOptions requestOptions) Get a specific user by ID (requires organization-scoped API key)ScimClient.listUsers(ListUsersRequest request, RequestOptions requestOptions) List users in the organization (requires organization-scoped API key) -
Uses of RequestOptions in com.langfuse.client.resources.score
Methods in com.langfuse.client.resources.score with parameters of type RequestOptionsModifier and TypeMethodDescriptionScoreClient.create(CreateScoreRequest request, RequestOptions requestOptions) Create a score (supports both trace and session scores)voidScoreClient.delete(String scoreId, RequestOptions requestOptions) Delete a score (supports both trace and session scores) -
Uses of RequestOptions in com.langfuse.client.resources.scoreconfigs
Methods in com.langfuse.client.resources.scoreconfigs with parameters of type RequestOptionsModifier and TypeMethodDescriptionScoreConfigsClient.create(CreateScoreConfigRequest request, RequestOptions requestOptions) Create a score configuration (config).ScoreConfigsClient.get(GetScoreConfigsRequest request, RequestOptions requestOptions) Get all score configsScoreConfigsClient.getById(String configId, RequestOptions requestOptions) Get a score config -
Uses of RequestOptions in com.langfuse.client.resources.scorev2
Methods in com.langfuse.client.resources.scorev2 with parameters of type RequestOptionsModifier and TypeMethodDescriptionScoreV2Client.get(GetScoresRequest request, RequestOptions requestOptions) Get a list of scores (supports both trace and session scores)ScoreV2Client.getById(String scoreId, RequestOptions requestOptions) Get a score (supports both trace and session scores) -
Uses of RequestOptions in com.langfuse.client.resources.sessions
Methods in com.langfuse.client.resources.sessions with parameters of type RequestOptionsModifier and TypeMethodDescriptionSessionsClient.get(String sessionId, RequestOptions requestOptions) Get a session.SessionsClient.list(GetSessionsRequest request, RequestOptions requestOptions) Get sessions -
Uses of RequestOptions in com.langfuse.client.resources.trace
Methods in com.langfuse.client.resources.trace with parameters of type RequestOptionsModifier and TypeMethodDescriptionTraceClient.delete(String traceId, RequestOptions requestOptions) Delete a specific traceTraceClient.deleteMultiple(DeleteTracesRequest request, RequestOptions requestOptions) Delete multiple tracesTraceClient.get(String traceId, RequestOptions requestOptions) Get a specific traceTraceClient.list(GetTracesRequest request, RequestOptions requestOptions) Get list of traces